Bridge profiles of a node across communities
Source:R/find_bridge_communities.R
find_bridge_communities.RdIdentifies which communities contribute most to the bridge role of a
given node, by decomposing its bridge connectivity into community-specific
contributions, excluding its own community when assigned. The function is
designed as an interpretative companion to bridge_metrics() and
bridge_metrics_excluded(), providing the components underlying
the corresponding overall bridge indices.
Value
An object of class "bridge_profiles" (a named list) with the
following components:
bridge_strengthBridge strength. List with
overall, the total value across all other communities, andby_comm, a tibble with community-specific contributions (community,sum_abs_w).bridge_ei1Bridge expected influence (order 1). List with
overallandby_comm(community,sum_signed_w).bridge_ei2Bridge expected influence (order 2). List with
overallandby_comm(community,sum_signed_w2).bridge_closenessBridge closeness. List with
overallandby_comm(community,inv_mean_dist).bridge_betweennessBridge betweenness. List with
overallandby_pair, a tibble with contributions by community pair (Ci,Cj,hits).
Details
Bridge connectivity is summarized using five complementary profiles: bridge strength, bridge EI1, bridge EI2, bridge closeness, and bridge betweenness.
Notes:
Bridge profiles are computed using only connections from the focal node to nodes in communities different from its own. If the focal node is not assigned to any community, i.e. excluded, connections to all assigned nodes in communities are considered.
Bridge betweenness is computed by counting all shortest paths between pairs of nodes in different communities that pass through the focal node as an intermediate vertex. When multiple shortest paths exist, each path is counted separately.