Compact textual summary for objects returned by mixMN() and
multimixMN(). The method reports:
whether the fit is single layer (
mixMN) or multilayer (multimixMN);number of subjects (if available) and variables;
for multilayer fits, the number of nodes and non-zero edges per layer and, if present, per interlayer pair;
size of the global graph (nodes and edges);
number of communities (single layer) or communities per layer (multilayer);
covariates used for adjustment and nodes excluded from the graph and/or clustering;
main settings for community detection and bootstrap;
data info.
Usage
# S3 method for class 'mixmashnet'
print(x, ...)Arguments
- x
An object of class
mixmashnet, returned bymixMN()ormultimixMN().- ...
Additional arguments.