Summarize MixMashNet fits (single and multilayer) in long format
Source:R/mixmashnet-summary.R
summary.mixmashnet.RdSummarizes fitted MixMashNet objects (single and multilayer). The summary includes the original estimates and, when available, bootstrap means, standard errors, and quantile regions.
Arguments
- object
An object of class
"mixmashnet"returned bymixMN()ormultimixMN().- what
Character string indicating which part of the model to summarize:
"intra": intralayer quantities (node-level indices and/or intralayer edges);"inter": interlayer quantities (node-level indices on the interlayer-only graph and/or cross-layer edges; multilayer fits only).
- statistics
Character vector specifying which statistics to include. For
what = "intra", valid values are:c("edges", "strength", "expected_influence", "closeness", "betweenness", "bridge_strength", "bridge_closeness", "bridge_betweenness", "bridge_ei1", "bridge_ei2", "bridge_strength_excluded", "bridge_betweenness_excluded", "bridge_closeness_excluded", "bridge_ei1_excluded", "bridge_ei2_excluded").For
what = "inter", valid values are:c("edges", "strength", "expected_influence", "closeness", "betweenness").If
statistics = NULL, then:for
what = "intra", all available intralayer statistics (including"edges") are returned;for
what = "inter", all available interlayer statistics (including"edges") are returned.
- layer
Optional character vector of layer names to subset. Used for
what = "intra"in multilayer fits. Ignored for single layer fits.- pairs
Optional character vector of layer-pair names (e.g.
"bio_dis") used forwhat = "inter"when summarizing interlayer edges. IfNULL, all available layer pairs are included. For interlayer node indices,pairscan be used to restrict the summary to nodes belonging to one of the layers in the given pair.- digits
Number of digits to round numeric summaries.
- ...
Not used (for S3 compatibility).